@@ -109,6 +109,11 @@ def _is_valid_extension(filename):
 
 def _load_content(name_or_path, profile_path):
     filename = None
+    optional = False
+
+    if name_or_path.endswith("?"):
+        optional = True
+        name_or_path = name_or_path[:-1]
 
     if _is_valid_extension(name_or_path):
         for path in profile_path:
@@ -117,9 +122,6 @@ def _load_content(name_or_path, profile_path):
                 # this is a full path that we can load
                 filename = filepath
                 break
-
-        if filename is None:
-            raise ProfileNotFound(name_or_path, profile_path)
     else:
         for path in profile_path:
             for ext in ("yml", "yaml"):
@@ -128,8 +130,10 @@ def _load_content(name_or_path, profile_path):
                     filename = filepath
                     break
 
-        if filename is None:
-            raise ProfileNotFound(name_or_path, profile_path)
+    if filename is None:
+        if optional:
+            return {}
+        raise ProfileNotFound(name_or_path, profile_path)
 
     with open(filename) as fct:
         try:
@@ -228,7 +232,7 @@ def _determine_pep8(profile_dict):
         return "full_pep8", True
     elif pep8 == "none":
         return "no_pep8", True
-    elif type(pep8) is dict and pep8.get("full", False):
+    elif isinstance(pep8, dict) and pep8.get("full", False):
         return "full_pep8", True
     return None, False
 
@@ -351,7 +355,7 @@ def _transform_legacy(profile_dict):
     # pycodestyle tool using the old name?
     if "pep8" in profile_dict:
         pep8conf = profile_dict["pep8"]
-        if type(pep8conf) is dict:
+        if isinstance(pep8conf, dict):
             # merge in with existing config if there is any
             out["pycodestyle"] = _simple_merge_dict(out.get("pycodestyle", {}), pep8conf)
         else:
